Module error_handler

Module error_handler 

Structs

ErrorHandlerLayer
Tower Layer that wraps a pipeline with error handling behaviour.
ErrorHandlerService
Tower Service that absorbs pipeline errors by retrying and/or forwarding to a DLC.