pub struct MulticastService { /* private fields */ }Expand description
Tower Service implementing the Multicast EIP.
Sends a message to multiple endpoints, processing each independently, and then aggregating the results.
Supports both sequential and parallel processing modes, configurable
via MulticastConfig::parallel. When parallel mode is enabled,
all endpoints are invoked concurrently with optional concurrency
limiting via MulticastConfig::parallel_limit.
Implementations
Sourceimpl MulticastService
impl MulticastService
Sourcepub fn new(endpoints: Vec<BoxProcessor>, config: MulticastConfig) -> Self
pub fn new(endpoints: Vec<BoxProcessor>, config: MulticastConfig) -> Self
Create a new MulticastService from a list of endpoints and a MulticastConfig.