Module remove_header

Module remove_header 

Structs

RemoveHeader
A processor that removes a header from the exchange’s input message.
RemoveHeaderLayer
A Tower Layer that wraps an inner service with a RemoveHeader.