pub struct RoutingSlipService { /* private fields */ }Expand description
Routing Slip EIP implementation.
Evaluates an expression once to get a list of endpoint URIs, then routes the message through them sequentially in a pipeline fashion.
Implementations
Sourceimpl RoutingSlipService
impl RoutingSlipService
pub fn new( config: RoutingSlipConfig, endpoint_resolver: EndpointResolver, ) -> Self