Module set_body

Module set_body 

Structs

SetBody
A processor that sets the message body using an expression closure. The closure receives the full exchange (read-only) and returns a new Body.
SetBodyLayer
A Tower Layer that wraps an inner service with a SetBody.