Module set_header

Module set_header 

Structs

SetHeader
A processor that sets a header on the exchange’s input message.
SetHeaderIfAbsent
A processor that sets a header on the exchange’s input message, but ONLY if the header is not already present (if-absent semantics).
SetHeaderLayer
A Tower Layer that wraps an inner service with a SetHeader.