Structs
- Splitter
Service - Tower Service implementing the Splitter EIP.
Constants
- CAMEL_
SPLIT_ COMPLETE - Property key indicating whether this fragment is the last one.
- CAMEL_
SPLIT_ INDEX - Property key for the zero-based index of a fragment within the split.
- CAMEL_
SPLIT_ SIZE - Property key for the total number of fragments produced by the split.