pub struct ValidateService { /* private fields */ }Expand description
Tower Service implementing the Validate EIP.
If the predicate returns true, the exchange continues (returned as Ok).
If false, a CamelError::ValidationError is returned.
Implementations
Sourceimpl ValidateService
impl ValidateService
Sourcepub fn new(
predicate: impl Fn(&Exchange) -> bool + Send + Sync + 'static,
expression_source: impl Into<String>,
) -> Self
pub fn new( predicate: impl Fn(&Exchange) -> bool + Send + Sync + 'static, expression_source: impl Into<String>, ) -> Self
Create from a closure predicate and an expression source string (for error messages).
Sourcepub fn from_predicate(
predicate: FilterPredicate,
expression_source: impl Into<String>,
) -> Self
pub fn from_predicate( predicate: FilterPredicate, expression_source: impl Into<String>, ) -> Self
Create from a pre-boxed FilterPredicate (used by resolve_steps).