Module dynamic_set_header

Module dynamic_set_header 

Structs

DynamicSetHeader
A processor that sets a header using an expression closure. The closure receives the full exchange (read-only) and returns a Value.
DynamicSetHeaderLayer
A Tower Layer that wraps an inner service with a DynamicSetHeader.