Structs
- Dynamic
SetHeader - A processor that sets a header using an expression closure. The closure receives the full exchange (read-only) and returns a Value.
- Dynamic
SetHeader Layer - A Tower Layer that wraps an inner service with a
DynamicSetHeader.