Structs
- SetHeader
- A processor that sets a header on the exchange’s input message.
- SetHeader
IfAbsent - A processor that sets a header on the exchange’s input message, but ONLY if the header is not already present (if-absent semantics).
- SetHeader
Layer - A Tower Layer that wraps an inner service with a
SetHeader.