Module splitter

Module splitter 

Structs

SplitterService
Tower Service implementing the Splitter EIP.

Constants

CAMEL_SPLIT_COMPLETE
Property key indicating whether this fragment is the last one.
CAMEL_SPLIT_INDEX
Property key for the zero-based index of a fragment within the split.
CAMEL_SPLIT_SIZE
Property key for the total number of fragments produced by the split.